@@ -15,6 +15,14 @@ Example:
 ```
 """
 
+from .__about__ import __version__
+from .__about__ import __author__
+from .__about__ import __email__
+from .__about__ import __github__
+
+__version__ = __version__
+__author__ = f'{__author__} <{__email__}> and <{__github__}>'
+
 __all__ = ['Froxy']
 
 from ._froxy import Froxy as Froxy
